@@ -1,6 +1,7 @@
 from zeep.client import CachingClient, Client  # noqa
 from zeep.transports import Transport  # noqa
 from zeep.plugins import Plugin  # noqa
+from zeep.settings import Settings  # noqa
 from zeep.xsd.valueobjects import AnyObject  # noqa
 
-__version__ = '2.5.0'
+__version__ = "3.4.0"
