@@ -5,6 +5,7 @@ from lxml import etree
 
 from zeep import exceptions, ns
 from zeep.loader import load_external
+from zeep.settings import Settings
 from zeep.xsd import const
 from zeep.xsd.elements import builtins as xsd_builtins_elements
 from zeep.xsd.types import builtins as xsd_builtins_types
@@ -16,15 +17,15 @@ logger = logging.getLogger(__name__)
 class Schema(object):
     """A schema is a collection of schema documents."""
 
-    def __init__(self, node=None, transport=None, location=None, strict=True):
+    def __init__(self, node=None, transport=None, location=None, settings=None):
         """
         :param node:
         :param transport:
         :param location:
-        :param strict: Boolean to indicate if the parsing is strict (default)
+        :param settings: The settings object
 
         """
-        self.strict = strict
+        self.settings = settings or Settings()
 
         self._transport = transport
 
@@ -43,25 +44,24 @@ class Schema(object):
     def __repr__(self):
         main_doc = self.root_document
         if main_doc:
-            return '<Schema(location=%r, tns=%r)>' % (
-                main_doc._location, main_doc._target_namespace)
-        return '<Schema()>'
+            return "<Schema(location=%r, tns=%r)>" % (
+                main_doc._location,
+                main_doc._target_namespace,
+            )
+        return "<Schema()>"
 
     @property
     def prefix_map(self):
         retval = {}
         retval.update(self._prefix_map_custom)
-        retval.update({
-            k: v for k, v in self._prefix_map_auto.items()
-            if v not in retval.values()
-        })
+        retval.update(
+            {k: v for k, v in self._prefix_map_auto.items() if v not in retval.values()}
+        )
         return retval
 
     @property
     def root_document(self):
-        return next(
-            (doc for doc in self.documents if not doc._is_internal),
-            None)
+        return next((doc for doc in self.documents if not doc._is_internal), None)
 
     @property
     def is_empty(self):
@@ -101,6 +101,13 @@ class Schema(object):
                     seen.add(type_.qname)
 
     def add_documents(self, schema_nodes, location):
+        """
+
+        :type schema_nodes: List[lxml.etree._Element]
+        :type location: str
+        :type target_namespace: Optional[str]
+
+        """
         resolve_queue = []
         for node in schema_nodes:
             document = self.create_new_document(node, location)
@@ -112,10 +119,7 @@ class Schema(object):
         self._prefix_map_auto = self._create_prefix_map()
 
     def add_document_by_url(self, url):
-        schema_node = load_external(
-            url,
-            self._transport,
-            strict=self.strict)
+        schema_node = load_external(url, self._transport, settings=self.settings)
 
         document = self.create_new_document(schema_node, url=url)
         document.resolve()
@@ -127,17 +131,18 @@ class Schema(object):
 
         """
         qname = self._create_qname(qname)
-        return self._get_instance(qname, 'get_element', 'element')
+        return self._get_instance(qname, "get_element", "element")
 
     def get_type(self, qname, fail_silently=False):
         """Return a global xsd.Type object with the given qname
 
         :rtype: zeep.xsd.ComplexType or zeep.xsd.AnySimpleType
 
+
         """
         qname = self._create_qname(qname)
         try:
-            return self._get_instance(qname, 'get_type', 'type')
+            return self._get_instance(qname, "get_type", "type")
         except exceptions.NamespaceError as exc:
             if fail_silently:
                 logger.debug(str(exc))
@@ -150,7 +155,7 @@ class Schema(object):
         :rtype: zeep.xsd.Group
 
         """
-        return self._get_instance(qname, 'get_group', 'group')
+        return self._get_instance(qname, "get_group", "group")
 
     def get_attribute(self, qname):
         """Return a global xsd.attributeGroup object with the given qname
@@ -158,7 +163,7 @@ class Schema(object):
         :rtype: zeep.xsd.Attribute
 
         """
-        return self._get_instance(qname, 'get_attribute', 'attribute')
+        return self._get_instance(qname, "get_attribute", "attribute")
 
     def get_attribute_group(self, qname):
         """Return a global xsd.attributeGroup object with the given qname
@@ -166,7 +171,7 @@ class Schema(object):
         :rtype: zeep.xsd.AttributeGroup
 
         """
-        return self._get_instance(qname, 'get_attribute_group', 'attributeGroup')
+        return self._get_instance(qname, "get_attribute_group", "attributeGroup")
 
     def set_ns_prefix(self, prefix, namespace):
         self._prefix_map_custom[prefix] = namespace
@@ -188,20 +193,21 @@ class Schema(object):
             if namespace == other_namespace:
                 return prefix
 
-        if namespace == 'http://schemas.xmlsoap.org/soap/envelope/':
-            return 'soap-env'
+        if namespace == "http://schemas.xmlsoap.org/soap/envelope/":
+            return "soap-env"
         return namespace
 
-    def create_new_document(self, node, url, base_url=None):
+    def create_new_document(self, node, url, base_url=None, target_namespace=None):
         """
 
         :rtype: zeep.xsd.schema.SchemaDocument
 
         """
-        namespace = node.get('targetNamespace') if node is not None else None
+        namespace = node.get("targetNamespace") if node is not None else None
+        if not namespace:
+            namespace = target_namespace
         if base_url is None:
             base_url = url
-
         schema = SchemaDocument(namespace, url, base_url)
         self.documents.add(schema)
         schema.load(self, node)
@@ -213,6 +219,10 @@ class Schema(object):
             self.documents.add(document)
         self._prefix_map_auto = self._create_prefix_map()
 
+    def deserialize(self, node):
+        elm = self.get_element(node.tag)
+        return elm.parse(node, schema=self)
+
     def _load_default_documents(self):
         schema = SchemaDocument(ns.XSD, None, None)
 
@@ -243,10 +253,13 @@ class Schema(object):
             raise last_exception
 
         except exceptions.NamespaceError:
-            raise exceptions.NamespaceError((
-                "Unable to resolve %s %s. " +
-                "No schema available for the namespace %r."
-            ) % (name, qname.text, qname.namespace))
+            raise exceptions.NamespaceError(
+                (
+                    "Unable to resolve %s %s. "
+                    + "No schema available for the namespace %r."
+                )
+                % (name, qname.text, qname.namespace)
+            )
 
     def _create_qname(self, name):
         """Create an `lxml.etree.QName()` object for the given qname string.
@@ -259,28 +272,25 @@ class Schema(object):
         if isinstance(name, etree.QName):
             return name
 
-        if not name.startswith('{') and ':' in name and self._prefix_map_auto:
-            prefix, localname = name.split(':', 1)
+        if not name.startswith("{") and ":" in name and self._prefix_map_auto:
+            prefix, localname = name.split(":", 1)
             if prefix in self._prefix_map_custom:
                 return etree.QName(self._prefix_map_custom[prefix], localname)
             elif prefix in self._prefix_map_auto:
                 return etree.QName(self._prefix_map_auto[prefix], localname)
             else:
-                raise ValueError(
-                    "No namespace defined for the prefix %r" % prefix)
+                raise ValueError("No namespace defined for the prefix %r" % prefix)
         else:
             return etree.QName(name)
 
     def _create_prefix_map(self):
-        prefix_map = {
-            'xsd': 'http://www.w3.org/2001/XMLSchema',
-        }
+        prefix_map = {"xsd": "http://www.w3.org/2001/XMLSchema"}
         i = 0
         for namespace in self.documents.get_all_namespaces():
             if namespace is None or namespace in prefix_map.values():
                 continue
 
-            prefix_map['ns%d' % i] = namespace
+            prefix_map["ns%d" % i] = namespace
             i += 1
         return prefix_map
 
@@ -319,7 +329,9 @@ class _SchemaContainer(object):
         :param document: zeep.xsd.schema.SchemaDocument
 
         """
-        logger.debug("Add document with tns %s to schema %s", document.namespace, id(self))
+        logger.debug(
+            "Add document with tns %s to schema %s", document.namespace, id(self)
+        )
         documents = self._instances.setdefault(document.namespace, [])
         documents.append(document)
 
@@ -331,7 +343,8 @@ class _SchemaContainer(object):
             if fail_silently:
                 return []
             raise exceptions.NamespaceError(
-                "No schema available for the namespace %r" % namespace)
+                "No schema available for the namespace %r" % namespace
+            )
         return self._instances[namespace]
 
     def get_by_namespace_and_location(self, namespace, location):
@@ -374,6 +387,7 @@ class SchemaDocument(object):
         self._location = location
         self._target_namespace = namespace
         self._is_internal = False
+        self._has_empty_import = False
 
         # Containers for specific types
         self._attribute_groups = {}
@@ -383,14 +397,17 @@ class SchemaDocument(object):
         self._types = {}
 
         self._imports = OrderedDict()
-        self._element_form = 'unqualified'
-        self._attribute_form = 'unqualified'
+        self._element_form = "unqualified"
+        self._attribute_form = "unqualified"
         self._resolved = False
         # self._xml_schema = None
 
     def __repr__(self):
-        return '<SchemaDocument(location=%r, tns=%r, is_empty=%r)>' % (
-            self._location, self._target_namespace, self.is_empty)
+        return "<SchemaDocument(location=%r, tns=%r, is_empty=%r)>" % (
+            self._location,
+            self._target_namespace,
+            self.is_empty,
+        )
 
     @property
     def namespace(self):
@@ -412,8 +429,9 @@ class SchemaDocument(object):
 
         if not schema.documents.has_schema_document_for_ns(self._target_namespace):
             raise RuntimeError(
-                "The document needs to be registered in the schema before " +
-                "it can be loaded")
+                "The document needs to be registered in the schema before "
+                + "it can be loaded"
+            )
 
         # Disable XML schema validation for now
         # if len(node) > 0:
@@ -443,12 +461,14 @@ class SchemaDocument(object):
                     (
                         "Unable to resolve %(item_name)s %(qname)s in "
                         "%(file)s. (via %(parent)s)"
-                    ) % {
-                        'item_name': exc.item_name,
-                        'qname': exc.qname,
-                        'file': exc.location,
-                        'parent': obj.qname,
-                    })
+                    )
+                    % {
+                        "item_name": exc.item_name,
+                        "qname": exc.qname,
+                        "file": exc.location,
+                        "parent": obj.qname,
+                    }
+                )
 
         _resolve_dict(self._attribute_groups)
         _resolve_dict(self._attributes)
@@ -476,7 +496,7 @@ class SchemaDocument(object):
         :type value: zeep.xsd.Type
 
         """
-        self._add_component(qname, value, self._types, 'type')
+        self._add_component(qname, value, self._types, "type")
 
     def register_element(self, qname, value):
         """Register a xsd.Element in this schema
@@ -485,7 +505,7 @@ class SchemaDocument(object):
         :type value: zeep.xsd.Element
 
         """
-        self._add_component(qname, value, self._elements, 'element')
+        self._add_component(qname, value, self._elements, "element")
 
     def register_group(self, qname, value):
         """Register a xsd.Element in this schema
@@ -494,7 +514,7 @@ class SchemaDocument(object):
         :type value: zeep.xsd.Element
 
         """
-        self._add_component(qname, value, self._groups, 'group')
+        self._add_component(qname, value, self._groups, "group")
 
     def register_attribute(self, qname, value):
         """Register a xsd.Element in this schema
@@ -503,7 +523,7 @@ class SchemaDocument(object):
         :type value: zeep.xsd.Attribute
 
         """
-        self._add_component(qname, value, self._attributes, 'attribute')
+        self._add_component(qname, value, self._attributes, "attribute")
 
     def register_attribute_group(self, qname, value):
         """Register a xsd.Element in this schema
@@ -512,7 +532,7 @@ class SchemaDocument(object):
         :type value: zeep.xsd.Group
 
         """
-        self._add_component(qname, value, self._attribute_groups, 'attribute_group')
+        self._add_component(qname, value, self._attribute_groups, "attribute_group")
 
     def get_type(self, qname):
         """Return a xsd.Type object from this schema
@@ -520,7 +540,7 @@ class SchemaDocument(object):
         :rtype: zeep.xsd.ComplexType or zeep.xsd.AnySimpleType
 
         """
-        return self._get_component(qname, self._types, 'type')
+        return self._get_component(qname, self._types, "type")
 
     def get_element(self, qname):
         """Return a xsd.Element object from this schema
@@ -528,7 +548,7 @@ class SchemaDocument(object):
         :rtype: zeep.xsd.Element
 
         """
-        return self._get_component(qname, self._elements, 'element')
+        return self._get_component(qname, self._elements, "element")
 
     def get_group(self, qname):
         """Return a xsd.Group object from this schema.
@@ -536,7 +556,7 @@ class SchemaDocument(object):
         :rtype: zeep.xsd.Group
 
         """
-        return self._get_component(qname, self._groups, 'group')
+        return self._get_component(qname, self._groups, "group")
 
     def get_attribute(self, qname):
         """Return a xsd.Attribute object from this schema
@@ -544,7 +564,7 @@ class SchemaDocument(object):
         :rtype: zeep.xsd.Attribute
 
         """
-        return self._get_component(qname, self._attributes, 'attribute')
+        return self._get_component(qname, self._attributes, "attribute")
 
     def get_attribute_group(self, qname):
         """Return a xsd.AttributeGroup object from this schema
@@ -552,7 +572,7 @@ class SchemaDocument(object):
         :rtype: zeep.xsd.AttributeGroup
 
         """
-        return self._get_component(qname, self._attribute_groups, 'attributeGroup')
+        return self._get_component(qname, self._attribute_groups, "attributeGroup")
 
     def _add_component(self, name, value, items, item_name):
         if isinstance(name, etree.QName):
@@ -564,17 +584,20 @@ class SchemaDocument(object):
         try:
             return items[qname]
         except KeyError:
-            known_items = ', '.join(items.keys())
-            raise exceptions.LookupError((
-                "No %(item_name)s '%(localname)s' in namespace %(namespace)s. " +
-                "Available %(item_name_plural)s are: %(known_items)s"
-                ) % {
-                    'item_name': item_name,
-                    'item_name_plural': item_name + 's',
-                    'localname': qname.localname,
-                    'namespace': qname.namespace,
-                    'known_items': known_items or ' - '
+            known_items = ", ".join(items.keys())
+            raise exceptions.LookupError(
+                (
+                    "No %(item_name)s '%(localname)s' in namespace %(namespace)s. "
+                    + "Available %(item_name_plural)s are: %(known_items)s"
+                )
+                % {
+                    "item_name": item_name,
+                    "item_name_plural": item_name + "s",
+                    "localname": qname.localname,
+                    "namespace": qname.namespace,
+                    "known_items": known_items or " - ",
                 },
                 qname=qname,
                 item_name=item_name,
-                location=self._location)
+                location=self._location,
+            )
