@@ -3,7 +3,7 @@ from collections import OrderedDict
 
 from zeep.xsd.printer import PrettyPrinter
 
-__all__ = ['AnyObject', 'CompoundValue']
+__all__ = ["AnyObject", "CompoundValue"]
 
 
 class AnyObject(object):
@@ -19,8 +19,11 @@ class AnyObject(object):
         self.value = value
 
     def __repr__(self):
-        return '<%s(type=%r, value=%r)>' % (
-            self.__class__.__name__, self.xsd_elm, self.value)
+        return "<%s(type=%r, value=%r)>" % (
+            self.__class__.__name__,
+            self.xsd_elm,
+            self.value,
+        )
 
     def __deepcopy__(self, memo):
         return type(self)(self.xsd_elm, copy.deepcopy(self.value))
@@ -40,9 +43,9 @@ def _unpickle_compound_value(name, values):
     See CompoundValue.__reduce__
 
     """
-    cls = type(name, (CompoundValue,), {
-        '_xsd_type': None, '__module__': 'zeep.objects'
-    })
+    cls = type(
+        name, (CompoundValue,), {"_xsd_type": None, "__module__": "zeep.objects"}
+    )
     obj = cls()
     obj.__values__ = values
     return obj
@@ -54,8 +57,10 @@ class ArrayValue(list):
 
     def as_value_object(self):
         anon_type = type(
-            self.__class__.__name__, (CompoundValue,),
-            {'_xsd_type': self._xsd_type, '__module__': 'zeep.objects'})
+            self.__class__.__name__,
+            (CompoundValue,),
+            {"_xsd_type": self._xsd_type, "__module__": "zeep.objects"},
+        )
         return anon_type(list(self))
 
     @classmethod
@@ -93,7 +98,7 @@ class CompoundValue(object):
         self.__values__ = values
 
     def __reduce__(self):
-        return (_unpickle_compound_value, (self.__class__.__name__, self.__values__,))
+        return (_unpickle_compound_value, (self.__class__.__name__, self.__values__))
 
     def __contains__(self, key):
         return self.__values__.__contains__(key)
@@ -127,25 +132,25 @@ class CompoundValue(object):
         self.__values__[key] = value
 
     def __setattr__(self, key, value):
-        if key.startswith('__') or key in ('_xsd_type', '_xsd_elm'):
+        if key.startswith("__") or key in ("_xsd_type", "_xsd_elm"):
             return super(CompoundValue, self).__setattr__(key, value)
         self.__values__[key] = value
 
     def __getattribute__(self, key):
-        if key.startswith('__') or key in ('_xsd_type', '_xsd_elm'):
+        if key.startswith("__") or key in ("_xsd_type", "_xsd_elm"):
             return super(CompoundValue, self).__getattribute__(key)
         try:
             return self.__values__[key]
         except KeyError:
             raise AttributeError(
-                "%s instance has no attribute '%s'" % (
-                    self.__class__.__name__, key))
+                "%s instance has no attribute '%s'" % (self.__class__.__name__, key)
+            )
 
     def __deepcopy__(self, memo):
         new = type(self)()
         new.__values__ = copy.deepcopy(self.__values__)
         for attr, value in self.__dict__.items():
-            if attr != '__values__':
+            if attr != "__values__":
                 setattr(new, attr, value)
         return new
 
@@ -190,16 +195,16 @@ def _process_signature(xsd_type, args, kwargs):
 
         if num_args > index:
             raise TypeError(
-                "__init__() takes at most %s positional arguments (%s given)" % (
-                    len(result), num_args))
+                "__init__() takes at most %s positional arguments (%s given)"
+                % (len(result), num_args)
+            )
 
     # Process the named arguments (sequence/group/all/choice). The
     # available_kwargs set is modified in-place.
     available_kwargs = set(kwargs.keys())
     for element_name, element in xsd_type.elements_nested:
         if element.accepts_multiple:
-            values = element.parse_kwargs(
-                kwargs, element_name, available_kwargs)
+            values = element.parse_kwargs(kwargs, element_name, available_kwargs)
         else:
             values = element.parse_kwargs(kwargs, None, available_kwargs)
 
@@ -217,17 +222,18 @@ def _process_signature(xsd_type, args, kwargs):
 
     # _raw_elements is a special kwarg used for unexpected unparseable xml
     # elements (e.g. for soap:header or when strict is disabled)
-    if '_raw_elements' in available_kwargs and kwargs['_raw_elements']:
-        result['_raw_elements'] = kwargs['_raw_elements']
-        available_kwargs.remove('_raw_elements')
+    if "_raw_elements" in available_kwargs and kwargs["_raw_elements"]:
+        result["_raw_elements"] = kwargs["_raw_elements"]
+        available_kwargs.remove("_raw_elements")
 
     if available_kwargs:
-        raise TypeError((
-            "%s() got an unexpected keyword argument %r. " +
-            "Signature: `%s`"
-        ) % (
-            xsd_type.qname or 'ComplexType',
-            next(iter(available_kwargs)),
-            xsd_type.signature(standalone=False)))
+        raise TypeError(
+            ("%s() got an unexpected keyword argument %r. " + "Signature: `%s`")
+            % (
+                xsd_type.qname or "ComplexType",
+                next(iter(available_kwargs)),
+                xsd_type.signature(standalone=False),
+            )
+        )
 
     return result
