@@ -12,7 +12,9 @@ from zeep.wsdl.messages import xop
 
 
 def test_rebuild_xml():
-    data = '\r\n'.join(line.strip() for line in """
+    data = "\r\n".join(
+        line.strip()
+        for line in """
         --MIME_boundary
         Content-Type: application/soap+xml; charset=UTF-8
         Content-Transfer-Encoding: 8bit
@@ -39,19 +41,21 @@ def test_rebuild_xml():
         ...binary JPG image...
 
         --MIME_boundary--
-    """.splitlines()).encode('utf-8')
+    """.splitlines()
+    ).encode("utf-8")
 
     response = stub(
         status_code=200,
         content=data,
         encoding=None,
         headers={
-            'Content-Type': 'multipart/related; boundary=MIME_boundary; type="application/soap+xml"; start="<claim@insurance.com>" 1'
-        }
+            "Content-Type": 'multipart/related; boundary=MIME_boundary; type="application/soap+xml"; start="<claim@insurance.com>" 1'
+        },
     )
 
     decoder = MultipartDecoder(
-        response.content, response.headers['Content-Type'], 'utf-8')
+        response.content, response.headers["Content-Type"], "utf-8"
+    )
 
     document = etree.fromstring(decoder.parts[0].content)
     message_pack = MessagePack(parts=decoder.parts[1:])
@@ -71,8 +75,9 @@ def test_rebuild_xml():
     assert_nodes_equal(etree.tostring(document), expected)
 
 
-def test_xop():
-    wsdl_main = StringIO("""
+def get_client_service():
+    wsdl_main = StringIO(
+        """
         <?xml version="1.0"?>
         <wsdl:definitions
           xmlns:wsdl="http://schemas.xmlsoap.org/wsdl/"
@@ -158,16 +163,25 @@ def test_xop():
             </wsdl:port>
           </wsdl:service>
         </wsdl:definitions>
-    """.strip())
+    """.strip()
+    )
 
     client = Client(wsdl_main, transport=Transport())
     service = client.create_service(
         "{http://tests.python-zeep.org/xsd-main}TestBinding",
-        "http://tests.python-zeep.org/test")
+        "http://tests.python-zeep.org/test",
+    )
 
+    return service
+
+
+def test_xop():
+    service = get_client_service()
     content_type = 'multipart/related; boundary="boundary"; type="application/xop+xml"; start="<soap:Envelope>"; start-info="application/soap+xml; charset=utf-8"'
 
-    response1 = '\r\n'.join(line.strip() for line in """
+    response1 = "\r\n".join(
+        line.strip()
+        for line in """
         Content-Type: application/xop+xml; charset=utf-8; type="application/soap+xml"
         Content-Transfer-Encoding: binary
         Content-ID: <soap:Envelope>
@@ -192,9 +206,12 @@ def test_xop():
 
         BINARYDATA
         --boundary--
-    """.splitlines())
+    """.splitlines()
+    )
 
-    response2 = '\r\n'.join(line.strip() for line in """
+    response2 = "\r\n".join(
+        line.strip()
+        for line in """
         Content-Type: application/xop+xml; charset=utf-8; type="application/soap+xml"
         Content-Transfer-Encoding: binary
         Content-ID: <soap:Envelope>
@@ -220,19 +237,68 @@ def test_xop():
         BINARYDATA
 
         --boundary--
-    """.splitlines())
+    """.splitlines()
+    )
 
     print(response1)
     with requests_mock.mock() as m:
-        m.post('http://tests.python-zeep.org/test',
-               content=response2.encode("utf-8"),
-               headers={"Content-Type": content_type})
+        m.post(
+            "http://tests.python-zeep.org/test",
+            content=response2.encode("utf-8"),
+            headers={"Content-Type": content_type},
+        )
         result = service.TestOperation2("")
         assert result["_value_1"] == "BINARYDATA".encode()
 
         m.post(
-            'http://tests.python-zeep.org/test',
+            "http://tests.python-zeep.org/test",
             content=response1.encode("utf-8"),
-            headers={"Content-Type": content_type})
+            headers={"Content-Type": content_type},
+        )
         result = service.TestOperation1("")
         assert result == "BINARYDATA".encode()
+
+
+def test_xop_cid_encoded():
+    service = get_client_service()
+    content_type = 'multipart/related; boundary="boundary"; type="application/xop+xml"; start="<soap:Envelope>"; start-info="application/soap+xml; charset=utf-8"'
+
+    response_encoded_cid = "\r\n".join(
+        line.strip()
+        for line in """
+            Content-Type: application/xop+xml; charset=utf-8; type="application/soap+xml"
+            Content-Transfer-Encoding: binary
+            Content-ID: <soap:Envelope>
+
+            <?xml version="1.0" encoding="UTF-8"?>
+            <soap:Envelope
+                xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/"
+                xmlns:xop="http://www.w3.org/2004/08/xop/include"
+                xmlns:test="http://tests.python-zeep.org/xsd-main">
+                <soap:Body>
+                    <test:resultComplex>
+                        <test:BinaryData>
+                            <xop:Include href="cid:test_encoding%20cid%25%24%7D%40"/>
+                        </test:BinaryData>
+                    </test:resultComplex>
+                </soap:Body>
+            </soap:Envelope>
+            --boundary
+            Content-Type: application/binary
+            Content-Transfer-Encoding: binary
+            Content-ID: <test_encoding cid%$}@>
+
+            BINARYDATA
+
+            --boundary--
+        """.splitlines()
+    )
+
+    with requests_mock.mock() as m:
+        m.post(
+            "http://tests.python-zeep.org/test",
+            content=response_encoded_cid.encode("utf-8"),
+            headers={"Content-Type": content_type},
+        )
+        result = service.TestOperation2("")
+        assert result["_value_1"] == "BINARYDATA".encode()
