@@ -1,9 +1,10 @@
 import datetime
 import os
+
 import pytest
 import requests_mock
-
 from freezegun import freeze_time
+
 from tests.utils import assert_nodes_equal, load_xml
 from zeep import client
 from zeep.wsse import UsernameToken
@@ -13,8 +14,8 @@ from zeep.wsse.utils import WSU
 @pytest.mark.requests
 def test_integration():
     client_obj = client.Client(
-        'tests/wsdl_files/soap.wsdl',
-        wsse=UsernameToken('username', 'password'))
+        "tests/wsdl_files/soap.wsdl", wsse=UsernameToken("username", "password")
+    )
 
     response = """
     <?xml version="1.0"?>
@@ -31,13 +32,14 @@ def test_integration():
     """.strip()
 
     with requests_mock.mock() as m:
-        m.post('http://example.com/stockquote', text=response)
-        result = client_obj.service.GetLastTradePrice('foobar')
+        m.post("http://example.com/stockquote", text=response)
+        result = client_obj.service.GetLastTradePrice("foobar")
         assert result == 120.123
 
 
 def test_password_text():
-    envelope = load_xml("""
+    envelope = load_xml(
+        """
         <soap-env:Envelope
             xmlns:ns0="http://example.com/stockquote.xsd"
             xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
@@ -52,9 +54,10 @@ def test_password_text():
             </ns0:TradePriceRequest>
           </soap-env:Body>
         </soap-env:Envelope>
-    """)
+    """
+    )
 
-    token = UsernameToken('michael', 'geheim')
+    token = UsernameToken("michael", "geheim")
     envelope, headers = token.apply(envelope, {})
     expected = """
         <soap-env:Envelope
@@ -82,11 +85,12 @@ def test_password_text():
     assert_nodes_equal(envelope, expected)
 
 
-@freeze_time('2016-05-08 12:00:00')
+@freeze_time("2016-05-08 12:00:00")
 def test_password_digest(monkeypatch):
-    monkeypatch.setattr(os, 'urandom', lambda x: b'mocked-random')
+    monkeypatch.setattr(os, "urandom", lambda x: b"mocked-random")
 
-    envelope = load_xml("""
+    envelope = load_xml(
+        """
         <soap-env:Envelope
             xmlns:ns0="http://example.com/stockquote.xsd"
             xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
@@ -101,9 +105,10 @@ def test_password_digest(monkeypatch):
             </ns0:TradePriceRequest>
           </soap-env:Body>
         </soap-env:Envelope>
-    """)
+    """
+    )
 
-    token = UsernameToken('michael', 'geheim', use_digest=True)
+    token = UsernameToken("michael", "geheim", use_digest=True)
     envelope, headers = token.apply(envelope, {})
     expected = """
         <soap-env:Envelope
@@ -133,11 +138,12 @@ def test_password_digest(monkeypatch):
     assert_nodes_equal(envelope, expected)
 
 
-@freeze_time('2016-05-08 12:00:00')
+@freeze_time("2016-05-08 12:00:00")
 def test_password_digest_custom(monkeypatch):
-    monkeypatch.setattr(os, 'urandom', lambda x: b'mocked-random')
+    monkeypatch.setattr(os, "urandom", lambda x: b"mocked-random")
 
-    envelope = load_xml("""
+    envelope = load_xml(
+        """
         <soap-env:Envelope
             xmlns:ns0="http://example.com/stockquote.xsd"
             xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
@@ -152,12 +158,17 @@ def test_password_digest_custom(monkeypatch):
             </ns0:TradePriceRequest>
           </soap-env:Body>
         </soap-env:Envelope>
-    """)
+    """
+    )
 
     created = datetime.datetime(2016, 6, 4, 20, 10)
     token = UsernameToken(
-        'michael', password_digest='12345', use_digest=True,
-        nonce='iets', created=created)
+        "michael",
+        password_digest="12345",
+        use_digest=True,
+        nonce="iets",
+        created=created,
+    )
     envelope, headers = token.apply(envelope, {})
     expected = """
         <soap-env:Envelope
@@ -188,7 +199,8 @@ def test_password_digest_custom(monkeypatch):
 
 
 def test_password_prepared():
-    envelope = load_xml("""
+    envelope = load_xml(
+        """
         <soap-env:Envelope
             xmlns:ns0="http://example.com/stockquote.xsd"
             xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
@@ -208,9 +220,10 @@ def test_password_prepared():
             </ns0:TradePriceRequest>
           </soap-env:Body>
         </soap-env:Envelope>
-    """)  # noqa
+    """
+    )  # noqa
 
-    token = UsernameToken('michael', 'geheim')
+    token = UsernameToken("michael", "geheim")
     envelope, headers = token.apply(envelope, {})
     expected = """
         <soap-env:Envelope
@@ -239,7 +252,8 @@ def test_password_prepared():
 
 
 def test_timestamp_token():
-    envelope = load_xml("""
+    envelope = load_xml(
+        """
             <soap-env:Envelope
                 xmlns:ns0="http://example.com/stockquote.xsd"
                 xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/"
@@ -260,16 +274,23 @@ def test_timestamp_token():
                 </ns0:TradePriceRequest>
               </soap-env:Body>
             </soap-env:Envelope>
-        """)  # noqa
+        """
+    )  # noqa
 
     timestamp_token = WSU.Timestamp()
-    timestamp_token.attrib['Id'] = 'id-21a27a50-9ebf-49cc-96bf-fcf7131e7858'
+    timestamp_token.attrib["Id"] = "id-21a27a50-9ebf-49cc-96bf-fcf7131e7858"
     some_date_obj = datetime.datetime(2018, 11, 18, 15, 44, 27, 440252)
-    timestamp_elements = [WSU.Created(some_date_obj.strftime("%Y-%m-%dT%H:%M:%SZ")),
-                          WSU.Expires((some_date_obj + datetime.timedelta(minutes=10)).strftime("%Y-%m-%dT%H:%M:%SZ"))]
+    timestamp_elements = [
+        WSU.Created(some_date_obj.strftime("%Y-%m-%dT%H:%M:%SZ")),
+        WSU.Expires(
+            (some_date_obj + datetime.timedelta(minutes=10)).strftime(
+                "%Y-%m-%dT%H:%M:%SZ"
+            )
+        ),
+    ]
     timestamp_token.extend(timestamp_elements)
 
-    token = UsernameToken('Vishu', 'Guntupalli', timestamp_token=timestamp_token)
+    token = UsernameToken("Vishu", "Guntupalli", timestamp_token=timestamp_token)
     envelope, headers = token.apply(envelope, {})
     expected = """
             <soap-env:Envelope
