@@ -4,12 +4,14 @@ import pytest
 from lxml import etree
 
 from tests.utils import assert_nodes_equal, load_xml, render_node
-from zeep.exceptions import ValidationError
 from zeep import xsd
+from zeep.exceptions import ValidationError
 
 
 def get_any_schema():
-    return xsd.Schema(load_xml("""
+    return xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -24,11 +26,15 @@ def get_any_schema():
             </complexType>
           </element>
         </schema>
-    """))
+    """
+        )
+    )
 
 
 def test_default_xsd_type():
-    schema = xsd.Schema(load_xml("""
+    schema = xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -36,25 +42,27 @@ def test_default_xsd_type():
                 elementFormDefault="qualified">
           <element name="container"/>
         </schema>
-    """))
+    """
+        )
+    )
     assert schema
 
-    container_cls = schema.get_element('ns0:container')
+    container_cls = schema.get_element("ns0:container")
     data = container_cls()
-    assert data == ''
+    assert data == ""
 
 
 def test_any_simple():
     schema = get_any_schema()
 
-    item_elm = schema.get_element('{http://tests.python-zeep.org/}item')
+    item_elm = schema.get_element("{http://tests.python-zeep.org/}item")
     assert isinstance(item_elm.type, xsd.String)
 
-    container_elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_elm = schema.get_element("{http://tests.python-zeep.org/}container")
 
     # Create via arg
-    obj = container_elm(xsd.AnyObject(item_elm, item_elm('argh')))
-    node = etree.Element('document')
+    obj = container_elm(xsd.AnyObject(item_elm, item_elm("argh")))
+    node = etree.Element("document")
     container_elm.render(node, obj)
     expected = """
         <document>
@@ -65,11 +73,11 @@ def test_any_simple():
     """
     assert_nodes_equal(expected, node)
     item = container_elm.parse(list(node)[0], schema)
-    assert item._value_1 == 'argh'
+    assert item._value_1 == "argh"
 
     # Create via kwarg _value_1
-    obj = container_elm(_value_1=xsd.AnyObject(item_elm, item_elm('argh')))
-    node = etree.Element('document')
+    obj = container_elm(_value_1=xsd.AnyObject(item_elm, item_elm("argh")))
+    node = etree.Element("document")
     container_elm.render(node, obj)
     expected = """
         <document>
@@ -80,20 +88,20 @@ def test_any_simple():
     """
     assert_nodes_equal(expected, node)
     item = container_elm.parse(list(node)[0], schema)
-    assert item._value_1 == 'argh'
+    assert item._value_1 == "argh"
 
 
 def test_any_value_element_tree():
     schema = get_any_schema()
 
-    item = etree.Element('{http://tests.python-zeep.org}lxml')
-    etree.SubElement(item, 'node').text = 'foo'
+    item = etree.Element("{http://tests.python-zeep.org}lxml")
+    etree.SubElement(item, "node").text = "foo"
 
-    container_elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_elm = schema.get_element("{http://tests.python-zeep.org/}container")
 
     # Create via arg
     obj = container_elm(item)
-    node = etree.Element('document')
+    node = etree.Element("document")
     container_elm.render(node, obj)
     expected = """
         <document>
@@ -107,7 +115,7 @@ def test_any_value_element_tree():
     assert_nodes_equal(expected, node)
     item = container_elm.parse(list(node)[0], schema)
     assert isinstance(item._value_1, etree._Element)
-    assert item._value_1.tag == '{http://tests.python-zeep.org}lxml'
+    assert item._value_1.tag == "{http://tests.python-zeep.org}lxml"
 
 
 def test_any_value_invalid():
@@ -116,19 +124,21 @@ def test_any_value_invalid():
     class SomeThing(object):
         pass
 
-    container_elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_elm = schema.get_element("{http://tests.python-zeep.org/}container")
 
     # Create via arg
     item = SomeThing()
     obj = container_elm(item)
-    node = etree.Element('document')
+    node = etree.Element("document")
 
     with pytest.raises(TypeError):
         container_elm.render(node, obj)
 
 
 def test_any_without_element():
-    schema = xsd.Schema(load_xml("""
+    schema = xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -144,9 +154,13 @@ def test_any_without_element():
             </complexType>
           </element>
         </schema>
-    """))
-    item_elm = schema.get_element('{http://tests.python-zeep.org/}item')
-    item = item_elm(xsd.AnyObject(xsd.String(), 'foobar'), type='attr-1', title='attr-2')
+    """
+        )
+    )
+    item_elm = schema.get_element("{http://tests.python-zeep.org/}item")
+    item = item_elm(
+        xsd.AnyObject(xsd.String(), "foobar"), type="attr-1", title="attr-2"
+    )
 
     node = render_node(item_elm, item)
     expected = """
@@ -157,13 +171,15 @@ def test_any_without_element():
     assert_nodes_equal(expected, node)
 
     item = item_elm.parse(list(node)[0], schema)
-    assert item.type == 'attr-1'
-    assert item.title == 'attr-2'
+    assert item.type == "attr-1"
+    assert item.title == "attr-2"
     assert item._value_1 is None
 
 
 def test_any_with_ref():
-    schema = xsd.Schema(load_xml("""
+    schema = xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -180,18 +196,21 @@ def test_any_with_ref():
             </complexType>
           </element>
         </schema>
-    """))
+    """
+        )
+    )
 
-    item_elm = schema.get_element('{http://tests.python-zeep.org/}item')
+    item_elm = schema.get_element("{http://tests.python-zeep.org/}item")
     assert isinstance(item_elm.type, xsd.String)
 
-    container_elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_elm = schema.get_element("{http://tests.python-zeep.org/}container")
     obj = container_elm(
-        item='bar',
-        _value_1=xsd.AnyObject(item_elm, item_elm('argh')),
-        _value_2=xsd.AnyObject(item_elm, item_elm('ok')))
+        item="bar",
+        _value_1=xsd.AnyObject(item_elm, item_elm("argh")),
+        _value_2=xsd.AnyObject(item_elm, item_elm("ok")),
+    )
 
-    node = etree.Element('document')
+    node = etree.Element("document")
     container_elm.render(node, obj)
     expected = """
         <document>
@@ -204,12 +223,13 @@ def test_any_with_ref():
     """
     assert_nodes_equal(expected, node)
     item = container_elm.parse(list(node)[0], schema)
-    assert item.item == 'bar'
-    assert item._value_1 == 'argh'
+    assert item.item == "bar"
+    assert item._value_1 == "argh"
 
 
 def test_element_any_parse():
-    node = load_xml("""
+    node = load_xml(
+        """
         <xsd:schema
             elementFormDefault="qualified"
             targetNamespace="https://tests.python-zeep.org"
@@ -222,24 +242,28 @@ def test_element_any_parse():
             </xsd:complexType>
           </xsd:element>
         </xsd:schema>
-    """)
+    """
+    )
 
     schema = xsd.Schema(node)
 
-    node = load_xml("""
+    node = load_xml(
+        """
           <container xmlns="https://tests.python-zeep.org">
             <something>
               <contains>text</contains>
             </something>
           </container>
-    """)
+    """
+    )
 
-    elm = schema.get_element('ns0:container')
+    elm = schema.get_element("ns0:container")
     elm.parse(node, schema)
 
 
 def test_element_any_type():
-    node = etree.fromstring("""
+    node = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -253,13 +277,14 @@ def test_element_any_type():
             </complexType>
           </element>
         </schema>
-    """.strip())
+    """.strip()
+    )
     schema = xsd.Schema(node)
 
-    container_elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_elm = schema.get_element("{http://tests.python-zeep.org/}container")
     obj = container_elm(something=datetime.time(18, 29, 59))
 
-    node = etree.Element('document')
+    node = etree.Element("document")
     container_elm.render(node, obj)
     expected = """
         <document>
@@ -270,11 +295,12 @@ def test_element_any_type():
     """
     assert_nodes_equal(expected, node)
     item = container_elm.parse(list(node)[0], schema)
-    assert item.something == '18:29:59'
+    assert item.something == "18:29:59"
 
 
 def test_element_any_type_unknown_type():
-    node = etree.fromstring("""
+    node = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -288,24 +314,28 @@ def test_element_any_type_unknown_type():
             </complexType>
           </element>
         </schema>
-    """.strip())
+    """.strip()
+    )
     schema = xsd.Schema(node)
 
-    container_elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_elm = schema.get_element("{http://tests.python-zeep.org/}container")
 
-    node = load_xml("""
+    node = load_xml(
+        """
         <document xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
             <ns0:container xmlns:ns0="http://tests.python-zeep.org/">
                 <ns0:something xmlns:q1="http://microsoft.com/wsdl/types/" xsi:type="q1:guid">bar</ns0:something>
             </ns0:container>
         </document>
-    """)
+    """
+    )
     item = container_elm.parse(list(node)[0], schema)
-    assert item.something == 'bar'
+    assert item.something == "bar"
 
 
 def test_element_any_type_elements():
-    node = etree.fromstring("""
+    node = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -319,21 +349,24 @@ def test_element_any_type_elements():
             </complexType>
           </element>
         </schema>
-    """.strip())
+    """.strip()
+    )
     schema = xsd.Schema(node)
 
     Child = xsd.ComplexType(
-        xsd.Sequence([
-            xsd.Element('{http://tests.python-zeep.org/}item_1', xsd.String()),
-            xsd.Element('{http://tests.python-zeep.org/}item_2', xsd.String()),
-        ])
+        xsd.Sequence(
+            [
+                xsd.Element("{http://tests.python-zeep.org/}item_1", xsd.String()),
+                xsd.Element("{http://tests.python-zeep.org/}item_2", xsd.String()),
+            ]
+        )
     )
-    child = Child(item_1='item-1', item_2='item-2')
+    child = Child(item_1="item-1", item_2="item-2")
 
-    container_elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_elm = schema.get_element("{http://tests.python-zeep.org/}container")
     obj = container_elm(something=child)
 
-    node = etree.Element('document')
+    node = etree.Element("document")
     container_elm.render(node, obj)
     expected = """
         <document>
@@ -348,12 +381,14 @@ def test_element_any_type_elements():
     assert_nodes_equal(expected, node)
     item = container_elm.parse(list(node)[0], schema)
     assert len(item.something) == 2
-    assert item.something[0].text == 'item-1'
-    assert item.something[1].text == 'item-2'
+    assert item.something[0].text == "item-1"
+    assert item.something[1].text == "item-2"
 
 
 def test_any_in_nested_sequence():
-    schema = xsd.Schema(load_xml("""
+    schema = xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:tns="http://tests.python-zeep.org/"
@@ -379,21 +414,25 @@ def test_any_in_nested_sequence():
             </xsd:complexType>
           </xsd:element>
         </xsd:schema>
-    """))   # noqa
+    """
+        )
+    )  # noqa
 
-    container_elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_elm = schema.get_element("{http://tests.python-zeep.org/}container")
     assert container_elm.signature(schema) == (
-        'ns0:container(items: {_value_1: ANY}, version: xsd:string, _value_1: ANY[])')
+        "ns0:container(items: {_value_1: ANY}, version: xsd:string, _value_1: ANY[])"
+    )
 
-    something = schema.get_element('{http://tests.python-zeep.org/}something')
-    foobar = schema.get_element('{http://tests.python-zeep.org/}foobar')
+    something = schema.get_element("{http://tests.python-zeep.org/}something")
+    foobar = schema.get_element("{http://tests.python-zeep.org/}foobar")
 
     any_1 = xsd.AnyObject(something, datetime.date(2016, 7, 4))
     any_2 = xsd.AnyObject(foobar, True)
     obj = container_elm(
-        items={'_value_1': any_1}, version='str1234', _value_1=[any_1, any_2])
+        items={"_value_1": any_1}, version="str1234", _value_1=[any_1, any_2]
+    )
 
-    node = etree.Element('document')
+    node = etree.Element("document")
     container_elm.render(node, obj)
     expected = """
         <document>
@@ -410,12 +449,13 @@ def test_any_in_nested_sequence():
     assert_nodes_equal(expected, node)
     item = container_elm.parse(list(node)[0], schema)
     assert item.items._value_1 == datetime.date(2016, 7, 4)
-    assert item.version == 'str1234'
+    assert item.version == "str1234"
     assert item._value_1 == [datetime.date(2016, 7, 4), True]
 
 
 def test_element_any_parse_inline_schema():
-    node = load_xml("""
+    node = load_xml(
+        """
         <xsd:schema
             elementFormDefault="qualified"
             targetNamespace="https://tests.python-zeep.org"
@@ -429,11 +469,13 @@ def test_element_any_parse_inline_schema():
             </xsd:complexType>
           </xsd:element>
         </xsd:schema>
-    """)
+    """
+    )
 
     schema = xsd.Schema(node)
 
-    node = load_xml("""
+    node = load_xml(
+        """
         <OstatDepoResult>
             <xs:schema id="OD" xmlns="" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
                 <xs:element name="OD" msdata:IsDataSet="true" msdata:UseCurrentLocale="true">
@@ -458,15 +500,18 @@ def test_element_any_parse_inline_schema():
                 </OD>
             </diffgr:diffgram>
         </OstatDepoResult>
-    """)
+    """
+    )
 
-    elm = schema.get_element('ns0:container')
+    elm = schema.get_element("ns0:container")
     data = elm.parse(node, schema)
-    assert data._value_1._value_1[0]['odr']['item'] == 'hetwerkt'
+    assert data._value_1._value_1[0]["odr"]["item"] == "hetwerkt"
 
 
 def test_any_missing():
-    schema = xsd.Schema(load_xml("""
+    schema = xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -486,18 +531,22 @@ def test_any_missing():
             </complexType>
           </element>
         </schema>
-    """))
+    """
+        )
+    )
 
-    container_elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_elm = schema.get_element("{http://tests.python-zeep.org/}container")
     obj = container_elm({})
 
-    node = etree.Element('document')
+    node = etree.Element("document")
     with pytest.raises(ValidationError):
         container_elm.render(node, obj)
 
 
 def test_any_optional():
-    schema = xsd.Schema(load_xml("""
+    schema = xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -517,12 +566,14 @@ def test_any_optional():
             </complexType>
           </element>
         </schema>
-    """))
+    """
+        )
+    )
 
-    container_elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_elm = schema.get_element("{http://tests.python-zeep.org/}container")
     obj = container_elm({})
 
-    node = etree.Element('document')
+    node = etree.Element("document")
     container_elm.render(node, obj)
     expected = """
         <document>
