@@ -1,4 +1,5 @@
 import io
+
 import pytest
 from lxml import etree
 
@@ -11,31 +12,31 @@ from zeep.xsd.types.unresolved import UnresolvedType
 
 def test_default_types():
     schema = xsd.Schema()
-    xsd_string = schema.get_type('{http://www.w3.org/2001/XMLSchema}string')
+    xsd_string = schema.get_type("{http://www.w3.org/2001/XMLSchema}string")
     assert xsd_string == xsd.String()
 
 
 def test_default_types_not_found():
     schema = xsd.Schema()
     with pytest.raises(exceptions.LookupError):
-        schema.get_type('{http://www.w3.org/2001/XMLSchema}bar')
+        schema.get_type("{http://www.w3.org/2001/XMLSchema}bar")
 
 
 def test_default_elements():
     schema = xsd.Schema()
-    xsd_schema = schema.get_element('{http://www.w3.org/2001/XMLSchema}schema')
+    xsd_schema = schema.get_element("{http://www.w3.org/2001/XMLSchema}schema")
     isinstance(xsd_schema, Schema)
 
 
 def test_default_elements_not_found():
     schema = xsd.Schema()
     with pytest.raises(exceptions.LookupError):
-        schema.get_element('{http://www.w3.org/2001/XMLSchema}bar')
+        schema.get_element("{http://www.w3.org/2001/XMLSchema}bar")
 
 
 def test_invalid_namespace_handling():
     schema = xsd.Schema()
-    qname = '{http://tests.python-zeep.org/404}foo'
+    qname = "{http://tests.python-zeep.org/404}foo"
 
     with pytest.raises(exceptions.NamespaceError) as exc:
         schema.get_element(qname)
@@ -59,7 +60,9 @@ def test_invalid_namespace_handling():
 
 
 def test_invalid_localname_handling():
-    schema = xsd.Schema(load_xml("""
+    schema = xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -67,11 +70,13 @@ def test_invalid_localname_handling():
             targetNamespace="http://tests.python-zeep.org/"
             elementFormDefault="qualified">
         </xs:schema>
-    """))
+    """
+        )
+    )
 
-    qname = '{http://tests.python-zeep.org/}foo'
-    namespace = 'http://tests.python-zeep.org/'
-    localname = 'foo'
+    qname = "{http://tests.python-zeep.org/}foo"
+    namespace = "http://tests.python-zeep.org/"
+    localname = "foo"
 
     with pytest.raises(exceptions.LookupError) as exc:
         schema.get_element(qname)
@@ -105,7 +110,9 @@ def test_schema_repr_none():
 
 
 def test_schema_repr_val():
-    schema = xsd.Schema(load_xml("""
+    schema = xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -113,12 +120,18 @@ def test_schema_repr_val():
             targetNamespace="http://tests.python-zeep.org/"
             elementFormDefault="qualified">
         </xs:schema>
-    """))
-    assert repr(schema) == "<Schema(location=None, tns='http://tests.python-zeep.org/')>"
+    """
+        )
+    )
+    assert (
+        repr(schema) == "<Schema(location=None, tns='http://tests.python-zeep.org/')>"
+    )
 
 
 def test_schema_doc_repr_val():
-    schema = xsd.Schema(load_xml("""
+    schema = xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -126,15 +139,21 @@ def test_schema_doc_repr_val():
             targetNamespace="http://tests.python-zeep.org/"
             elementFormDefault="qualified">
         </xs:schema>
-    """))
-    docs = schema._get_schema_documents('http://tests.python-zeep.org/')
+    """
+        )
+    )
+    docs = schema._get_schema_documents("http://tests.python-zeep.org/")
     assert len(docs) == 1
     doc = docs[0]
-    assert repr(doc) == "<SchemaDocument(location=None, tns='http://tests.python-zeep.org/', is_empty=True)>"
+    assert (
+        repr(doc)
+        == "<SchemaDocument(location=None, tns='http://tests.python-zeep.org/', is_empty=True)>"
+    )
 
 
 def test_multiple_extension():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -155,9 +174,11 @@ def test_multiple_extension():
             <xs:element name="typetje" type="tns:type_a"/>
 
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_b = etree.fromstring("""
+    node_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -176,9 +197,11 @@ def test_multiple_extension():
               </xs:complexContent>
             </xs:complexType>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_c = etree.fromstring("""
+    node_c = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -196,20 +219,22 @@ def test_multiple_extension():
                 <xs:attribute name="wat" type="xs:string" />
             </xs:complexType>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
     etree.XMLSchema(node_c)
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/b.xsd', node_b)
-    transport.bind('http://tests.python-zeep.org/c.xsd', node_c)
+    transport.bind("http://tests.python-zeep.org/b.xsd", node_b)
+    transport.bind("http://tests.python-zeep.org/c.xsd", node_c)
 
     schema = xsd.Schema(node_a, transport=transport)
-    type_a = schema.get_type('ns0:type_a')
-    type_a(wat='x')
+    type_a = schema.get_type("ns0:type_a")
+    type_a(wat="x")
 
 
 def test_global_element_and_type():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -230,9 +255,11 @@ def test_global_element_and_type():
             </xs:complexType>
 
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_b = etree.fromstring("""
+    node_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -248,9 +275,11 @@ def test_global_element_and_type():
             <xs:element name="ref_elm" type="xs:string"/>
             <xs:attribute name="ref_attr" type="xs:string"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_c = etree.fromstring("""
+    node_c = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -265,28 +294,30 @@ def test_global_element_and_type():
             </xs:complexType>
             <xs:element name="item" type="xs:string"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
     etree.XMLSchema(node_c)
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/b.xsd', node_b)
-    transport.bind('http://tests.python-zeep.org/c.xsd', node_c)
+    transport.bind("http://tests.python-zeep.org/b.xsd", node_b)
+    transport.bind("http://tests.python-zeep.org/c.xsd", node_c)
 
     schema = xsd.Schema(node_a, transport=transport)
-    type_a = schema.get_type('{http://tests.python-zeep.org/c}type_a')
+    type_a = schema.get_type("{http://tests.python-zeep.org/c}type_a")
 
-    type_a = schema.get_type('{http://tests.python-zeep.org/c}type_a')
-    type_a(item_a='x')
+    type_a = schema.get_type("{http://tests.python-zeep.org/c}type_a")
+    type_a(item_a="x")
 
-    elm = schema.get_element('{http://tests.python-zeep.org/c}item')
-    elm('x')
+    elm = schema.get_element("{http://tests.python-zeep.org/c}item")
+    elm("x")
 
-    elm = schema.get_type('{http://tests.python-zeep.org/a}refs')
-    elm(ref_elm='foo', ref_attr='bar')
+    elm = schema.get_type("{http://tests.python-zeep.org/a}refs")
+    elm(ref_elm="foo", ref_attr="bar")
 
 
 def test_cyclic_imports():
-    schema_a = etree.fromstring("""
+    schema_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -299,9 +330,11 @@ def test_cyclic_imports():
                 schemaLocation="http://tests.python-zeep.org/b.xsd"
                 namespace="http://tests.python-zeep.org/b"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    schema_b = etree.fromstring("""
+    schema_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -314,9 +347,11 @@ def test_cyclic_imports():
                 schemaLocation="http://tests.python-zeep.org/c.xsd"
                 namespace="http://tests.python-zeep.org/c"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    schema_c = etree.fromstring("""
+    schema_c = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -328,17 +363,21 @@ def test_cyclic_imports():
                 schemaLocation="http://tests.python-zeep.org/a.xsd"
                 namespace="http://tests.python-zeep.org/a"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/a.xsd', schema_a)
-    transport.bind('http://tests.python-zeep.org/b.xsd', schema_b)
-    transport.bind('http://tests.python-zeep.org/c.xsd', schema_c)
-    xsd.Schema(schema_a, transport=transport, location='http://tests.python-zeep.org/a.xsd')
+    transport.bind("http://tests.python-zeep.org/a.xsd", schema_a)
+    transport.bind("http://tests.python-zeep.org/b.xsd", schema_b)
+    transport.bind("http://tests.python-zeep.org/c.xsd", schema_c)
+    xsd.Schema(
+        schema_a, transport=transport, location="http://tests.python-zeep.org/a.xsd"
+    )
 
 
 def test_get_type_through_import():
-    schema_a = etree.fromstring("""
+    schema_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -353,9 +392,11 @@ def test_get_type_through_import():
             <xs:element name="foo" type="b:bar"/>
 
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    schema_b = etree.fromstring("""
+    schema_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -367,16 +408,18 @@ def test_get_type_through_import():
             <xs:complexType name="bar"/>
 
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/a.xsd', schema_a)
-    transport.bind('http://tests.python-zeep.org/b.xsd', schema_b)
+    transport.bind("http://tests.python-zeep.org/a.xsd", schema_a)
+    transport.bind("http://tests.python-zeep.org/b.xsd", schema_b)
     xsd.Schema(schema_a, transport=transport)
 
 
 def test_duplicate_target_namespace():
-    schema_a = etree.fromstring("""
+    schema_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -391,9 +434,11 @@ def test_duplicate_target_namespace():
                 schemaLocation="http://tests.python-zeep.org/c.xsd"
                 namespace="http://tests.python-zeep.org/duplicate"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    schema_b = etree.fromstring("""
+    schema_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -408,9 +453,11 @@ def test_duplicate_target_namespace():
               </xsd:sequence>
             </xsd:complexType>
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
 
-    schema_c = etree.fromstring("""
+    schema_c = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -426,22 +473,24 @@ def test_duplicate_target_namespace():
             </xsd:complexType>
 
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/a.xsd', schema_a)
-    transport.bind('http://tests.python-zeep.org/b.xsd', schema_b)
-    transport.bind('http://tests.python-zeep.org/c.xsd', schema_c)
+    transport.bind("http://tests.python-zeep.org/a.xsd", schema_a)
+    transport.bind("http://tests.python-zeep.org/b.xsd", schema_b)
+    transport.bind("http://tests.python-zeep.org/c.xsd", schema_c)
     schema = xsd.Schema(schema_a, transport=transport)
 
-    elm_b = schema.get_element('{http://tests.python-zeep.org/duplicate}elm-in-b')
-    elm_c = schema.get_element('{http://tests.python-zeep.org/duplicate}elm-in-c')
+    elm_b = schema.get_element("{http://tests.python-zeep.org/duplicate}elm-in-b")
+    elm_c = schema.get_element("{http://tests.python-zeep.org/duplicate}elm-in-c")
     assert not isinstance(elm_b.type, UnresolvedType)
     assert not isinstance(elm_c.type, UnresolvedType)
 
 
 def test_multiple_no_namespace():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -452,24 +501,28 @@ def test_multiple_no_namespace():
           <xsd:import schemaLocation="http://tests.python-zeep.org/b.xsd"/>
           <xsd:import schemaLocation="http://tests.python-zeep.org/c.xsd"/>
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_b = etree.fromstring("""
+    node_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
             elementFormDefault="qualified">
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/b.xsd', node_b)
-    transport.bind('http://tests.python-zeep.org/c.xsd', node_b)
+    transport.bind("http://tests.python-zeep.org/b.xsd", node_b)
+    transport.bind("http://tests.python-zeep.org/c.xsd", node_b)
     xsd.Schema(node_a, transport=transport)
 
 
 def test_multiple_only_target_ns():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -480,25 +533,29 @@ def test_multiple_only_target_ns():
           <xsd:import schemaLocation="http://tests.python-zeep.org/b.xsd"/>
           <xsd:import schemaLocation="http://tests.python-zeep.org/c.xsd"/>
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_b = etree.fromstring("""
+    node_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
             elementFormDefault="qualified"
             targetNamespace="http://tests.python-zeep.org/duplicate-ns">
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/b.xsd', node_b)
-    transport.bind('http://tests.python-zeep.org/c.xsd', node_b)
+    transport.bind("http://tests.python-zeep.org/b.xsd", node_b)
+    transport.bind("http://tests.python-zeep.org/c.xsd", node_b)
     xsd.Schema(node_a, transport=transport)
 
 
 def test_schema_error_handling():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -508,26 +565,28 @@ def test_schema_error_handling():
             elementFormDefault="qualified">
 
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
     transport = DummyTransport()
     schema = xsd.Schema(node_a, transport=transport)
 
     with pytest.raises(ValueError):
-        schema.get_element('nonexisting:something')
+        schema.get_element("nonexisting:something")
     with pytest.raises(ValueError):
-        schema.get_type('nonexisting:something')
+        schema.get_type("nonexisting:something")
     with pytest.raises(exceptions.NamespaceError):
-        schema.get_element('{nonexisting}something')
+        schema.get_element("{nonexisting}something")
     with pytest.raises(exceptions.NamespaceError):
-        schema.get_type('{nonexisting}something')
+        schema.get_type("{nonexisting}something")
     with pytest.raises(exceptions.LookupError):
-        schema.get_element('ns0:something')
+        schema.get_element("ns0:something")
     with pytest.raises(exceptions.LookupError):
-        schema.get_type('ns0:something')
+        schema.get_type("ns0:something")
 
 
 def test_schema_import_xmlsoap():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -537,13 +596,15 @@ def test_schema_import_xmlsoap():
             elementFormDefault="qualified">
           <xsd:import namespace="http://schemas.xmlsoap.org/soap/encoding/"/>
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
     transport = DummyTransport()
     xsd.Schema(node_a, transport=transport)
 
 
 def test_schema_import_unresolved():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -553,13 +614,15 @@ def test_schema_import_unresolved():
             elementFormDefault="qualified">
           <xsd:import namespace="http://schemas.xmlsoap.org/soap/encoding/"/>
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
     transport = DummyTransport()
     xsd.Schema(node_a, transport=transport)
 
 
 def test_no_target_namespace():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -578,24 +641,28 @@ def test_no_target_namespace():
           </xsd:element>
 
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_b = etree.fromstring("""
+    node_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
             elementFormDefault="qualified">
             <xsd:element name="bla" type="xsd:string"/>
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/b.xsd', node_b)
+    transport.bind("http://tests.python-zeep.org/b.xsd", node_b)
     xsd.Schema(node_a, transport=transport)
 
 
 def test_include_recursion():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -609,9 +676,11 @@ def test_include_recursion():
                 namespace="http://tests.python-zeep.org/b"/>
 
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_b = etree.fromstring("""
+    node_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -622,9 +691,11 @@ def test_include_recursion():
             <xs:include schemaLocation="http://tests.python-zeep.org/c.xsd"/>
             <xs:element name="bar" type="xs:string"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_c = etree.fromstring("""
+    node_c = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -636,19 +707,21 @@ def test_include_recursion():
 
             <xs:element name="foo" type="xs:string"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/b.xsd', node_b)
-    transport.bind('http://tests.python-zeep.org/c.xsd', node_c)
+    transport.bind("http://tests.python-zeep.org/b.xsd", node_b)
+    transport.bind("http://tests.python-zeep.org/c.xsd", node_c)
 
     schema = xsd.Schema(node_a, transport=transport)
-    schema.get_element('{http://tests.python-zeep.org/b}foo')
-    schema.get_element('{http://tests.python-zeep.org/b}bar')
+    schema.get_element("{http://tests.python-zeep.org/b}foo")
+    schema.get_element("{http://tests.python-zeep.org/b}bar")
 
 
 def test_include_relative():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns="http://tests.python-zeep.org/tns"
@@ -659,34 +732,40 @@ def test_include_relative():
             <xs:include schemaLocation="http://tests.python-zeep.org/subdir/b.xsd"/>
 
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_b = etree.fromstring("""
+    node_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema" elementFormDefault="qualified">
             <xs:include schemaLocation="c.xsd"/>
             <xs:element name="bar" type="xs:string"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_c = etree.fromstring("""
+    node_c = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema" elementFormDefault="qualified">
             <xs:element name="foo" type="xs:string"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/subdir/b.xsd', node_b)
-    transport.bind('http://tests.python-zeep.org/subdir/c.xsd', node_c)
+    transport.bind("http://tests.python-zeep.org/subdir/b.xsd", node_b)
+    transport.bind("http://tests.python-zeep.org/subdir/c.xsd", node_c)
 
     schema = xsd.Schema(node_a, transport=transport)
-    schema.get_element('{http://tests.python-zeep.org/a}foo')
-    schema.get_element('{http://tests.python-zeep.org/a}bar')
+    schema.get_element("{http://tests.python-zeep.org/a}foo")
+    schema.get_element("{http://tests.python-zeep.org/a}bar")
 
 
 def test_include_no_default_namespace():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns="http://tests.python-zeep.org/tns"
@@ -699,10 +778,12 @@ def test_include_no_default_namespace():
 
             <xs:element name="container" type="foo"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
     # include without default namespace, other xsd prefix
-    node_b = etree.fromstring("""
+    node_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -718,12 +799,13 @@ def test_include_no_default_namespace():
               </xsd:sequence>
             </xsd:complexType>
         </xsd:schema>
-    """.strip())
+    """.strip()
+    )
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/b.xsd', node_b)
+    transport.bind("http://tests.python-zeep.org/b.xsd", node_b)
     schema = xsd.Schema(node_a, transport=transport)
-    item = schema.get_element('{http://tests.python-zeep.org/tns}container')
+    item = schema.get_element("{http://tests.python-zeep.org/tns}container")
     assert item
 
 
@@ -800,13 +882,14 @@ def test_include_no_parent_default_namespace():
     schema_include = etree.fromstring(schema_include)
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/tns.xsd', schema_tns)
-    transport.bind('http://tests.python-zeep.org/include.xsd', schema_include)
+    transport.bind("http://tests.python-zeep.org/tns.xsd", schema_tns)
+    transport.bind("http://tests.python-zeep.org/include.xsd", schema_include)
     xsd.Schema(schema_root, transport=transport)
 
 
 def test_include_different_form_defaults():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns="http://tests.python-zeep.org/"
@@ -816,10 +899,12 @@ def test_include_different_form_defaults():
             <xs:include
                 schemaLocation="http://tests.python-zeep.org/b.xsd"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
     # include without default namespace, other xsd prefix
-    node_b = load_xml("""
+    node_b = load_xml(
+        """
         <?xml version="1.0"?>
         <xsd:schema
             elementFormDefault="qualified"
@@ -836,28 +921,32 @@ def test_include_different_form_defaults():
               <xsd:attribute name="attr" type="xsd:string"/>
             </xsd:complexType>
         </xsd:schema>
-    """)
+    """
+    )
 
     transport = DummyTransport()
-    transport.bind('http://tests.python-zeep.org/b.xsd', node_b)
+    transport.bind("http://tests.python-zeep.org/b.xsd", node_b)
 
     schema = xsd.Schema(node_a, transport=transport)
-    item = schema.get_element('{http://tests.python-zeep.org/}container')
-    obj = item(item='foo', attr='bar')
+    item = schema.get_element("{http://tests.python-zeep.org/}container")
+    obj = item(item="foo", attr="bar")
     node = render_node(item, obj)
 
-    expected = load_xml("""
+    expected = load_xml(
+        """
         <document>
           <ns0:container xmlns:ns0="http://tests.python-zeep.org/" ns0:attr="bar">
             <ns0:item>foo</ns0:item>
           </ns0:container>
         </document>
-    """)
+    """
+    )
     assert_nodes_equal(expected, node)
 
 
 def test_merge():
-    node_a = etree.fromstring("""
+    node_a = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -867,9 +956,11 @@ def test_merge():
             elementFormDefault="qualified">
           <xs:element name="foo" type="xs:string"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
-    node_b = etree.fromstring("""
+    node_b = etree.fromstring(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -878,18 +969,20 @@ def test_merge():
             elementFormDefault="qualified">
           <xs:element name="foo" type="xs:int"/>
         </xs:schema>
-    """.strip())
+    """.strip()
+    )
 
     schema_a = xsd.Schema(node_a)
     schema_b = xsd.Schema(node_b)
     schema_a.merge(schema_b)
 
-    schema_a.get_element('{http://tests.python-zeep.org/a}foo')
-    schema_a.get_element('{http://tests.python-zeep.org/b}foo')
+    schema_a.get_element("{http://tests.python-zeep.org/a}foo")
+    schema_a.get_element("{http://tests.python-zeep.org/b}foo")
 
 
 def test_xml_namespace():
-    xmlns = load_xml("""
+    xmlns = load_xml(
+        """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -898,12 +991,15 @@ def test_xml_namespace():
             elementFormDefault="qualified">
           <xs:attribute name="lang" type="xs:string"/>
         </xs:schema>
-    """)
+    """
+    )
 
     transport = DummyTransport()
-    transport.bind('http://www.w3.org/2001/xml.xsd', xmlns)
+    transport.bind("http://www.w3.org/2001/xml.xsd", xmlns)
 
-    xsd.Schema(load_xml("""
+    xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -919,16 +1015,21 @@ def test_xml_namespace():
             </xs:complexType>
           </xs:element>
         </xs:schema>
-    """), transport=transport)
+    """
+        ),
+        transport=transport,
+    )
 
 
 def test_auto_import_known_schema():
-    content = io.open('tests/wsdl_files/soap-enc.xsd', 'rb').read()
+    content = io.open("tests/wsdl_files/soap-enc.xsd", "rb").read()
 
     transport = DummyTransport()
-    transport.bind('http://schemas.xmlsoap.org/soap/encoding/', content)
+    transport.bind("http://schemas.xmlsoap.org/soap/encoding/", content)
 
-    schema = xsd.Schema(load_xml("""
+    schema = xsd.Schema(
+        load_xml(
+            """
         <?xml version="1.0"?>
         <xs:schema
             xmlns:xs="http://www.w3.org/2001/XMLSchema"
@@ -939,6 +1040,9 @@ def test_auto_import_known_schema():
           <xs:import namespace="http://schemas.xmlsoap.org/soap/encoding/"/>
           <xs:group ref="soap-enc:Struct"/>
         </xs:schema>
-    """), transport=transport)
-    schema.set_ns_prefix('soap-enc', 'http://schemas.xmlsoap.org/soap/encoding/')
-    schema.get_group('soap-enc:Struct')
+    """
+        ),
+        transport=transport,
+    )
+    schema.set_ns_prefix("soap-enc", "http://schemas.xmlsoap.org/soap/encoding/")
+    schema.get_group("soap-enc:Struct")
